generate_api_key

Function generate_api_key 

pub fn generate_api_key() -> String
Mint a bearer token for an endpoint that is about to be exposed off loopback.

A v4 UUID: 122 random bits from the OS CSPRNG, and already the shape this workspace uses for the desktop app’s embedded-API token.